@@ -18,11 +18,11 @@ our @EXPORT_OK = qw(
 	modelsdir
 ); # symbols to export on request (WHY?)
 
-our $VERSION = '0.5';
+our $VERSION = '0.6';
 
 
 BEGIN {
-    $VERSION = '0.5';
+    $VERSION = '0.6';
     if ($] > 5.006) {
         require XSLoader;
         XSLoader::load(__PACKAGE__, $VERSION);
@@ -91,7 +91,7 @@ Image::DecodeQR::WeChat - Decode QR code(s) from images using the OpenCV/WeChat
 
 =head1 VERSION
 
-Version 0.5
+Version 0.6
 
 
 =head1 SYNOPSIS
@@ -100,8 +100,9 @@ This module provides a Perl interface to the OpenCV/WeChat QR code
 decoder via XS code.
 OpenCV/WeChat library uses CNN to do this with pre-trained models.
 
-This module has been tested with OpenCV v4.5.5 and Perl v5.32 on
-Linux.
+This module has been tested by myself with OpenCV v4.5.5 and Perl v5.32 on
+Linux. But check the CPANtesters matrix on the left for all the tests done
+on this module.
 
 The library is relatively successful even for rotated codes. It remains
 to be tested on the minimum size ofthe code images (60px in my case).
@@ -118,11 +119,11 @@ Here is some code to get you started:
 	'an-input-image.png',
 
 	# the dir with model parameters required by the library.
-	# These come with this package and are curtesy of WeChat
-	# which is part of OpenCV contrib packages
-        # They are installed with this package and their default location
+	# Model files come with this Perl module and are curtesy of WeChat
+	# which is part of OpenCV contrib packages.
+        # They are installed with this module and their default location
         # is given by Image::DecodeQR::WeChat::modelsdir()
-        # Alternatively, specify your own model files:
+        # Alternatively, you specify here your own model files:
 	Image::DecodeQR::WeChat::modelsdir(),
 
 	# outbase for all output files, optional
@@ -264,7 +265,7 @@ All the image formats of OpenCV's L<imread()|https://docs.opencv.org/4.5.5/d4/da
 are supported.
 
 =item * C<modelsdir> : the location of the directory holding all model files (CNN trained models)
-required for QR code detection. These models are already included with this package and will be
+required for QR code detection. These models are already included with this Perl module and will be
 installed in a shared dir during installation. Their total size is about 1MB.
 They have been kindly contributed by WeChat along with their library for QR Code detection.
 They can be found L<https://github.com/WeChatCV/opencv_3rdparty|here>. The installed
@@ -300,12 +301,14 @@ boxes. See C<outbase> above.
 =head3 C< decode(\%params) >
 
 
-This is a Perl wrapper to the C<decode_xs()> so that user can specify
-only a minimal set of parameters and the will be filled in by defaults.
+This is a Perl wrapper to the C<decode_xs()> and allows a user to specify
+only a minimal set of parameters with the rest to be filled in by defaults.
 
-Like L<decode_xs()>, it returns undef on failure.
+Like L<decode_xs()>, it returns undef on failure. Or an arrayref of
+two arrays. The C<payloads> array and the C<bounding-boxes> array.
+Each has a number of items equal to the QR codes detected.
 
-It returns an empty ARRAYref (i.e. a ref to an empty array)
+An ARRAYref of two empty arrays will be returned
 if no QR codes were found or decoded successfully.
 
 The C< params > hashref:
@@ -317,11 +320,11 @@ The C< params > hashref:
 =item * C<outbase> : optional, if specified payloads (QR-code text) will be dumped to a text file.
 If further, C<dumpqrimagestofile> is set to 1 then image files with the detected QR-codes will
 be dumped one for each QR-code as well as text files with payloads and bounding boxes wrt the
-input imaghe.
+input image.
 
 =item * C<modelsdir> : optional, use it only if you want to use your own model files (for their
 format have a look at L<https://docs.opencv.org/4.x/d5/d04/classcv_1_1wechat__qrcode_1_1WeChatQRCode.html>, they are CNN training files).
-This package has included the model files kindly submitted by WeChat as a contribution to OpenCV
+This Perl module has included the model files kindly submitted by WeChat as a contribution to OpenCV
 and will be installed in your system with all other files. Use C<modelsdir()> to see the location
 of installed model files. Their total size is about 1MB.
 
@@ -340,9 +343,12 @@ C< imshow() > (with C < highgui > enabled).
 
 =head3 C< modelsdir() >
 
-It returns the path where the models included in this package have been installed.
+It returns the path where the models included in this Perl module
+have been installed.
 This is useful when you want to use C<decode_xs()> and need to specify
-the C<modelsdir>. Just pass the output of this to C<decode_xs()> as its C<modelsdir> parameter.
+the C<modelsdir>.
+Just pass the output of this to C<decode_xs()> as its C<modelsdir> parameter.
+However, you can not set the location of your own modelsdir using C< modelsdir() >.
 
 =head3 C< opencv_has_highgui_xs() >
 
@@ -352,7 +358,7 @@ affects the option C<graphicaldisplayresult> to L<decode()> and L<decode_xs()>
 which will be ignored if there is no highgui support.
 
 Caveat: checking for whether current OpenCV installation has highgui
-support is very lame, it merely tries to find the include file C<< opencv2/highgui.hpp >>
+support is currently very lame, it merely tries to find the include file C<< opencv2/highgui.hpp >>
 in the Include dirs. I have tried several methods (see ```Makefile.PL```), for
 example L<DynaLoader> or L<FFI::CheckLib> can search for symbols in any library
 (e.g. searching for C<imshow()> in C<libopencv_highgui> or  C<libopencv_world>).
@@ -425,15 +431,15 @@ OpenCV from sources. This is the procedure I followed:
 
 =over
 
-=item 1. Download OpenCV sources and also its contributed modules.
+=item * Download OpenCV sources and also its contributed modules.
 
-=item 2. Extract the sources and change to the source dir.
+=item * Extract the sources and change to the source dir.
 
-=item 3. From within the source dir extract the contrib archive.
+=item * From within the source dir extract the contrib archive.
 
-=item 4. Create a C<build> dir and change to it.
+=item * Create a C<build> dir and change to it.
 
-=item 5. There are two ways to make C<cmake> just tolerable:
+=item * There are two ways to make C<cmake> just tolerable:
 C<cmake-gui> and C<ccmake>. The former is a full-gui interface
 to setting the billion C<cmake> variables. Use it
 if you are on a machine which offers a GUI: C<cmake-gui ..>
@@ -441,14 +447,14 @@ If you are on a headless or remote host possibly over telnet or ssh
 then do not despair because c<ccmake> is the CLI, curses-based
 equivalent to C<cmake-gui>,  use it like: C<ccmake ..> (from within the build dir).
 
-=item 6. Once on either of the cmake GUIs, first do a
+=item * Once on either of the cmake GUIs, first do a
 C<configure>, then check the
 list of all variables (you can search on both, for searching
 in the CLI, press C<</>> and then C<n> for next hit)
 to suit you and then C<generate>, quit
 and  C<VERBOSE=1 make -j4 all>
 
-=item 7. I guess, cmake variables you want to modify
+=item * I guess, cmake variables you want to modify
 are C<OPENCV_EXTRA_MODULES_PATH>
 and C<OPENCV_ENABLE_NONFREE> and anything that has to do with C<CNN> or C<DNN>.
 If you have CUDA installed and a CUDA-capable GPU then enable CUDA
@@ -456,11 +462,11 @@ If you have CUDA installed and a CUDA-capable GPU then enable CUDA
 Eigen3, Intel's TBB, CNN, DNN etc. You need to install all these
 additional packages to get OpenCV support with them.
 
-=item 8. I had a problem with compiling OpenCV with a GUI (the C<highgui>)
+=item * I had a problem with compiling OpenCV with a GUI (the C<highgui>)
 on a headless host. So, I just disabled it. That's easy to achieve
 during the above.
 
-=item 9. I have both installed this on a CUDA-capable GPU (with CUDA 10.2 installed)
+=item * I have both installed this on a CUDA-capable GPU (with CUDA 10.2 installed)
 host and on a headless remote host with no GPU or basic. CUDA is
 not required for building this module.
 
